@@ -150,6 +150,11 @@ $smarty->assign('input_use_detailpage_for_search',
 		$this->CreateInputYesNoDropdown($id,'use_detailpage_for_search',
 						$this->GetPreference('use_detailpage_for_search',0)));
 
+$smarty->assign('input_hierpage',
+		$contentops->CreateHierarchyDropdown('',$this->GetPreference('hierpage'),
+					       $id.'hierpage'));
+$smarty->assign('prettyhierurls',$this->GetPreference('prettyhierurls',0));
+
 $notfound_opts = array();
 $notfound_opts['do404'] = $this->Lang('prompt_notfound_404');
 $notfound_opts['do301'] = $this->Lang('prompt_notfound_301');
