@@ -44,7 +44,7 @@ $lang['categorylisttemplates'] = 'CategoryList Templates';
 $lang['categorylisttemplate_addedit'] = 'Add/Edit A CategoryList Template';
 $lang['centimeters'] = 'Centimeters';
 $lang['checkbox'] = 'Checkbox';
-$lang['confirm_copyattributes'] = 'Aany existing attribute sets for this product will be removed. Are you sure you want to continue?';
+$lang['confirm_copyattributes'] = 'Any existing attribute sets for this product will be removed. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'Are you sure you want to delete this node?  Any products that are using this node will be set to no hierarchy';
 $lang['confirm_import'] = "Are you sure you really want to do this?\\n\\nImproper settings, or an invalid config file could completely corrupt a currently valid and working system.";
 $lang['copy'] = 'Copy';
