@@ -39,9 +39,11 @@ $lang['categorylisttemplates'] = 'Kategorielisten-Templates';
 $lang['categorylisttemplate_addedit'] = ' Ein Kategorie-Listentemplate hinzuf&uuml;gen/&auml;ndern';
 $lang['centimeters'] = 'Zentimeter';
 $lang['checkbox'] = 'Kontrollk&auml;stchen';
+$lang['confirm_copyattributes'] = 'Aany existing attribute sets for this product will be removed. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'M&ouml;chten Sie diesen Knoten wirklich l&ouml;schen? Alle Artikel, die diesen Knoten nutzen, werden auf &quot;no hierarchy&quot; gesetzt';
 $lang['confirm_import'] = 'Wollen Sie dies WIRKLICH?\n\nFalsche Einstellungen oder eine ung&uuml;ltige Konfigurationsdatei k&ouml;nnen ein bislang funktionierendes System komplett zerst&ouml;ren.';
 $lang['copy'] = 'Kopieren';
+$lang['copy_attrib_sets'] = 'Atribut S&auml;tze kopieren';
 $lang['copy_category'] = 'Kategorie kopieren';
 $lang['createddate'] = 'Erstellungsdatum';
 $lang['current_value'] = 'Aktueller Wert';
@@ -54,11 +56,13 @@ $lang['delete_attribset'] = 'Attribut l&ouml;schen';
 $lang['delete_hierarchy_item'] = 'Hierarchie-Element l&ouml;schen';
 $lang['descending'] = 'Absteigend';
 $lang['description'] = 'Beschreibung';
+$lang['destination'] = 'Bestimmungsort';
 $lang['details'] = 'Details ';
 $lang['detailtemplates'] = 'Detail-Templates';
 $lang['detailtemplate_addedit'] = 'Ein Detail-Template hinzuf&uuml;gen/&auml;ndern';
 $lang['dimensions'] = 'Dimensionen';
 $lang['disabled'] = 'Deaktiviert';
+$lang['down'] = 'Nach unten';
 $lang['draft'] = 'Entwurf';
 $lang['dropdown'] = 'Listenfeld';
 $lang['dropdown_options'] = 'Listenfeld-Optionen <em>(nur in Listenfeld-Men&uuml;s einsetzbar)</em><br/><br/><em>(ein Eintrag pro Zeile)</em>';
@@ -78,6 +82,7 @@ $lang['error_filenotfound'] = 'Die Datei wurde nicht gefunden';
 $lang['error_fileopen'] = 'Problem beim &Ouml;ffnen der Datei %s';
 $lang['error_invalidparent'] = 'Ung&uuml;ltiges, &uuml;bergeordnetes Element (ein Hierarchieelement kann nicht sein eigenes &uuml;bergeordnetes Element sein)';
 $lang['error_invalid_name'] = 'Der eingegebene Wert im benutzerdefinierten Formular-Feld ist ung&uuml;ltig (beinhaltet nicht-alphanumerischen Zeichen)';
+$lang['error_invalid_value'] = 'Ung&uuml;ltiger Wert angegeben';
 $lang['error_missingparam'] = 'Ein ben&ouml;tigter Parameter fehlt oder ist ung&uuml;ltig';
 $lang['error_nameused'] = 'An Element mit diesem Namen existiert bereits';
 $lang['error_nofieldtype'] = 'Bitte w&auml;hlen Sie einen Feldtyp';
@@ -166,9 +171,11 @@ $lang['inches'] = 'Inches';
 $lang['include_children'] = 'Einschlie&szlig;lich Unterpunkte?';
 $lang['info_alnumonly'] = 'Nur alphanumerische Zeichen. Keine Leerzeichen, Zitate oder Buchstaben/Nummern-Kombinationen';
 $lang['info_attribtemplate'] = 'M&ouml;gliche Variablen sind: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
+$lang['info_attributes_copied'] = 'Atribute Kopiert';
 $lang['info_autowatermark'] = 'Es werden die Wasserzeichen-Einstellungen des CGExtensions-Moduls verwendet';
 $lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
 $lang['info_cart_module_params'] = 'Diese Parameter werden verwendet, um ein Warenkorb-Modul f&uuml;r die Artikel-Detail- und -Listenansicht auszuw&auml;hlen.';
+$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
 $lang['info_createfields'] = 'Unbekannte Artikelfelder automatisch erstellen? <em>(werden als Textfelder erstellt)</em>';
 $lang['info_createcategories'] = 'Automatically create product categories to match those of the CSV file, if it does not already exist';
 $lang['info_createhierarchy'] = 'Automatically create product hierarchies to match those of the CSV file if it does not already exist';
@@ -218,6 +225,7 @@ $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist acti
 $lang['param_detailpage'] = 'Dies legt die Seiten-ID (pageid) oder den Alias (alias) fest, welche(r) benutzt werden soll, um die Detailansicht auszugeben.';
 $lang['param_detailtemplate'] = 'Dieser Parameter wird verwendet, um das Template festzulegen, welches f&uuml;r die Artikel-Detailansicht verwendet werden soll. Ohne Vorgabe wird das Standard-Template verwendet.';
 $lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
+$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Dieser Parameter ist nur in der <em>default</em>-Ansicht sinnvoll. Er wird verwendet, um nur Artikel anzuzeigen, die einer bestimmten Hierarchie angeh&ouml;ren. Dabei k&ouml;nnen Wildcards verwendet werden, um &uuml;bergeordnete/untergeordnete Beziehungen ebenfalls anzuzeigen. Z.B. gibt {Products hierarchy=&#039;LKWs*&#039;} eine Zusammenfassung aller LKWs aus, einschlie&szlig;lich aller untergeordneten Elemente der Hierarchie. Genauso gibt {Products hierarchy=&#039;*LKWs&#039;} eine Zusammenfassung aller LKWs aus, einschlie&szlig;lich der &uuml;bergeordneten Elemente in der Hierarchie.';
 $lang['param_hierarchytemplate'] = 'Dieser Parameter wird verwendet, um das Template festzulegen, welches f&uuml;r die Hierarchieansicht verwendet werden soll. Ohne Vorgabe wird das Standard-Template verwendet.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
@@ -247,7 +255,6 @@ $lang['param_sortby'] = 'Dieser Parameter ist nur in der Listenansicht sinnvoll.
 $lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
 $lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
 $lang['param_summarytemplate'] = 'Dieser Parameter wird verwendet, um das Template festzulegen, welches f&uuml;r die Zusammenfassungsansicht verwendet werden soll. Ohne Vorgabe wird das Standard-Template verwendet.';
-$lang['param_useoldhierarchy'] = 'Use old hierarchy mode which generates a flat list of hierarchies below the current level.  This mode is deprecated and will be removed at a later date.';
 $lang['parent'] = '&Uuml;bergeordnetes Element';
 $lang['postinstall'] = 'Das Products-Modul wurde  installiert.';
 $lang['postuninstall'] = 'Das Products-Modul wurde einschlie&szlig;lich aller zugeh&ouml;rigen Daten entfernt.';
@@ -260,18 +267,20 @@ $lang['product'] = 'Artikel';
 $lang['productname'] = 'Artikel-Name';
 $lang['products'] = 'Artikel';
 $lang['product_detail_settings'] = 'Artikeldetail-Einstellungen';
+$lang['product_editing_settings'] = 'Produkt Bearbeitungsoptionen ';
+$lang['product_summary_settings'] = 'Produkt&uuml;bersicht Einstellungen';
 $lang['product_hierarchy'] = 'Artikel-Hierarchie';
 $lang['product_manager'] = 'Artikelverwaltung';
-$lang['progress'] = 'Progress';
+$lang['progress'] = 'Fortschritt';
 $lang['prompt'] = 'Eingabe';
 $lang['prompt_add_attribset'] = 'Attributeinstellungen hinzuf&uuml;gen/bearbeiten';
 $lang['prompt_allowed_filetypes'] = 'Das Hochladen von Dateien mit diesen Endungen (f&uuml;r Felder des Typs &#039;file&#039;) erlauben';
 $lang['prompt_allowed_imagetypes'] = 'Das Hochladen von Bildern mit diesen Endungen (f&uuml;r Felder des Typs &#039;image&#039;) erlauben';
-$lang['prompt_attribtemplate'] = 'Template for display of product attribute values in dropdown';
+$lang['prompt_attribtemplate'] = 'Template f&uuml;r die Anzeige von Produkt Attributwerte in Dropdown';
 $lang['prompt_autothumbnail'] = 'Vorschaubilder automatisch erzeugen';
 $lang['prompt_autothumbnail_size'] = 'Maximale Gr&ouml;&szlig;e der Vorschaubilder.';
 $lang['prompt_autopreviewimg'] = 'Automatisch Vorschaubilder der Bilder erstellen';
-$lang['prompt_autopreviewimg_size'] = 'Maximum size (largest dimension) of the preview image.';
+$lang['prompt_autopreviewimg_size'] = 'Maximale Gr&ouml;&szlig;e (gr&ouml;&szlig;te Ausdehnung) des Vorschaubildes.';
 $lang['prompt_autowatermark'] = 'Automatisch Wasserzeichen auf den Bildern erzeugen';
 $lang['prompt_applicable'] = 'Aktivierung per Voreinstellung f&uuml;r alle neuen Artikel';
 $lang['prompt_batchsize'] = 'Batch Size';
@@ -282,30 +291,31 @@ $lang['prompt_createfields'] = 'Artikelfelder erstellen?';
 $lang['prompt_createhierarchy'] = 'Eine Artikel-Hierarchie erstellen';
 $lang['prompt_csvfile'] = 'Eine CSV-Datei hochladen';
 $lang['prompt_currencycode'] = 'W&auml;hrungs-Zeichen';
-$lang['prompt_currencysymbol'] = 'W&auml;hrungszymbol';
+$lang['prompt_currencysymbol'] = 'W&auml;hrungssymbol';
 $lang['prompt_default_status'] = 'Voreingestellt haben alle neuen Artikel diesen Status';
 $lang['prompt_default_taxable'] = 'Voreingestellt enthalten alle neuen Artikel einen Steueranteil';
 $lang['prompt_deleteproductfiles'] = 'Alle zum Artikel geh&ouml;renden Dateien l&ouml;schen, wenn der Artikel gel&ouml;scht wird?';
 $lang['prompt_delimiter'] = 'Feldtrenner';
 $lang['prompt_detailpage'] = 'Voreingestellte Detail-Seite';
-$lang['prompt_detailsfor'] = 'Details for %s';
-$lang['prompt_duplicateproducts'] = 'How to handle duplicate products?';
-$lang['prompt_false'] = 'False';
+$lang['prompt_detailsfor'] = 'Details f&uuml;r %s';
+$lang['prompt_duplicateproducts'] = 'Wie sollen doppelte Produkte gehandhabt werden?';
+$lang['prompt_false'] = 'Nein';
 $lang['prompt_handleimages'] = 'Handle images?';
 $lang['prompt_imagepath'] = 'Bilderpfad';
-$lang['prompt_lengthunits'] = 'Length Units';
+$lang['prompt_lengthunits'] = 'L&auml;ngeneinheiten';
 $lang['prompt_notfound_behavior'] = 'Welche Aktion soll ausgef&uuml;hrt werden, wenn ein Artikel nicht angezeigt werden konnte?';
 $lang['prompt_notfound_404'] = 'Einen 404er Fehler erzeugen';
 $lang['prompt_notfound_301'] = 'Eine 301er Weiterleitung erzeugen';
 $lang['prompt_notfound_errormsg'] = 'Eine Fehlermeldung anzeigen';
 $lang['prompt_notfound_msg'] = 'Fehlermeldung, wenn ein Artikel nicht gefunden werden konnte';
-$lang['prompt_notfound_page'] = 'Page to do permanent redirect to?';
-$lang['prompt_prod_detailpage'] = 'Default Page for Product Detail Views';
-$lang['prompt_products_matching'] = 'Products matching %s';
+$lang['prompt_notfound_page'] = 'Seite f&uuml;r dauerhafte Umleitung?';
+$lang['prompt_prod_detailpage'] = 'Standardseite f&uuml;r Produkt Detailansicht';
+$lang['prompt_products_matching'] = 'Produkte passend %s';
+$lang['prompt_summarypagelimit'] = 'Voreingestelltes Produktlimit in der Listenansicht';
 $lang['prompt_summarysortorder'] = 'Voreingestellte Sortier-Reihenfolge in der Listenansicht';
 $lang['prompt_summarysorting'] = 'Voreingestelltes Sortier-Feld in der Listenansicht';
 $lang['prompt_template'] = 'Template-Quelle';
-$lang['prompt_true'] = 'True';
+$lang['prompt_true'] = 'Ja';
 $lang['prompt_urlprefix'] = 'Prefix to use on all URLS targeted to this this module';
 $lang['prompt_use_detailpage_for_search'] = 'Use this page for search results too <em>(overrides the searchresults page parameter in the search module)</em>';
 $lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
@@ -317,28 +327,29 @@ $lang['resettofactory'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;ck
 $lang['return'] = 'Zur&uuml;ck';
 $lang['return_to_top'] = 'Zur&uuml;ck nach oben';
 $lang['root'] = 'Wurzelverzeichnis';
-$lang['search_description'] = 'Search Property Description';
-$lang['search_expr'] = 'Should the query match all, or any of the tests below?';
-$lang['search_name'] = 'Search Property Name';
-$lang['search_price'] = 'Price Range';
-$lang['searchtemplate_addedit'] = 'Add/Edit Search Form Template';
-$lang['searchtemplates'] = 'Search Templates';
+$lang['search_description'] = 'Suche nach Eigenschaft Beschreibung';
+$lang['search_expr'] = 'Sollte die Abfrage f&uuml;r alle oder einen der Tests unten entsprechen?';
+$lang['search_name'] = 'Suche nach Eigenschaft Name';
+$lang['search_price'] = 'Preisspanne';
+$lang['searchtemplate_addedit'] = 'Hinzuf&uuml;gen/Bearbeiten Suchformular Template';
+$lang['searchtemplates'] = 'Suchformular Templates';
 $lang['select_one'] = 'Bitte ausw&auml;hlen';
 $lang['sku'] = 'Art.-Nr.';
 $lang['sort_by'] = 'Sortiert nach';
 $lang['sort_order'] = 'Sortier-Reihenfolge';
+$lang['source'] = 'Quelle';
 $lang['status'] = 'Status ';
 $lang['submit'] = 'Absenden';
-$lang['subscription'] = 'Subscription';
-$lang['subscr_expiry'] = 'Expiry';
-$lang['subscr_expiry2'] = 'Expires';
+$lang['subscription'] = 'Abonnement';
+$lang['subscr_expiry'] = 'Verfall';
+$lang['subscr_expiry2'] = 'Verf&auml;llt';
 $lang['subscr_monthly'] = 'Monatlich';
-$lang['subscr_delperiod'] = 'Delivery Frequency';
-$lang['subscr_delperiod2'] = 'Delievered';
-$lang['subscr_payperiod'] = 'Payment Frequency';
-$lang['subscr_payperiod2'] = 'Paid';
-$lang['subscr_quarterly'] = 'Quarterly';
-$lang['subscr_semianually'] = 'Semi Anually';
+$lang['subscr_delperiod'] = 'Liefer-H&auml;ufigkeit';
+$lang['subscr_delperiod2'] = 'Geliefert';
+$lang['subscr_payperiod'] = 'Zahlungs-H&auml;ufigkeit';
+$lang['subscr_payperiod2'] = 'Bezahlt';
+$lang['subscr_quarterly'] = 'Viertelj&auml;hrlich';
+$lang['subscr_semianually'] = 'Halbj&auml;hrlich';
 $lang['subscr_yearly'] = 'J&auml;hrlich';
 $lang['summarytemplates'] = 'Zusammenfassungs-Templates';
 $lang['summarytemplate_addedit'] = 'Ein Zusammenfassungs-Template hinzuf&uuml;gen/&auml;ndern';
@@ -349,23 +360,24 @@ $lang['textbox'] = 'Einzeiliges Textfeld';
 $lang['title_byhierarchy_dflttemplate'] = 'Voreinstellung Neues Hierarchie Ausgabe Template';
 $lang['title_categorylist_dflttemplate'] = 'Voreinstellung Neues Kategorie-Ausgabe Template';
 $lang['title_detail_dflttemplate'] = 'Voreinstellung Neues Artikel-Detailansicht Template';
-$lang['title_search_dflttemplate'] = 'Default New Search Template';
+$lang['title_search_dflttemplate'] = 'Voreinstellung Neues Suchformular Template';
 $lang['title_summary_dflttemplate'] = 'Voreinstellung Neues Artikel-Listenansicht Template';
 $lang['type'] = 'Typ';
+$lang['up'] = 'Nach oben';
 $lang['update'] = 'Aktualisieren';
 $lang['upload'] = 'Hochzuladende Datei ausw&auml;hlen';
 $lang['url_alias'] = 'URL-Alias';
 $lang['valid'] = 'G&uuml;ltig';
 $lang['value'] = 'Wert';
 $lang['values'] = 'Werte';
-$lang['view'] = 'View';
-$lang['viewable_fields'] = 'Select custom fields to view in the table';
+$lang['view'] = 'Anzeigen';
+$lang['viewable_fields'] = 'W&auml;hlen Sie benutzerdefinierte Felder in der Tabellenansicht';
 $lang['watermark_location'] = 'Platzierung des Wasserzeichens';
 $lang['weight'] = 'Gewicht';
 $lang['yes'] = 'Ja';
-$lang['qca'] = 'P0-75091478-1268421814072';
-$lang['utma'] = '156861353.728989452.1268567475.1274918139.1275330212.27';
+$lang['qca'] = 'P0-1458450664-1284573084918';
+$lang['utmz'] = '156861353.1292514844.633.43.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utma'] = '156861353.1164361908.1285153768.1292748011.1292751775.658';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1275330212.27.18.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.2.10.1292751775';
 ?>
\ No newline at end of file
