@@ -1,17 +1,17 @@
 <?php
-$lang['abbr_length'] = 'l';
-$lang['abbr_width'] = 'L';
-$lang['abbr_height'] = 'H';
+$lang['abbr_length'] = 'Larg.';
+$lang['abbr_width'] = 'Long.';
+$lang['abbr_height'] = 'Haut.';
 $lang['add'] = 'Ajouter';
 $lang['addcategory'] = 'Ajouter une cat&eacute;gorie';
 $lang['addfielddef'] = 'Ajouter un champ';
 $lang['adjustable'] = 'Ajustable';
 $lang['addproduct'] = 'Ajouter un produit';
 $lang['add_attrib_set'] = 'Ajouter un attribut';
-$lang['add_category_field'] = 'Associe un champ &agrave; la cat&eacute;gorie: &quot;%s&quot;';
+$lang['add_category_field'] = 'Associe un champ &agrave; la cat&eacute;gorie : &quot;%s&quot;';
 $lang['add_hierarchy_item'] = 'Ajoute une hi&eacute;rarchie d&#039;article';
 $lang['add_option'] = 'Ajouter une option d&#039;attribut';
-$lang['admin_only'] = 'Seuls les administrateurs peuvent voir cet attribut?';
+$lang['admin_only'] = 'Seuls les administrateurs peuvent voir cet attribut ?';
 $lang['align_ul'] = 'Haut gauche';
 $lang['align_uc'] = 'Haut centre';
 $lang['align_ur'] = 'Haut droit';
@@ -24,7 +24,7 @@ $lang['align_lr'] = 'Bas droit';
 $lang['all'] = 'Tous';
 $lang['allcategories'] = 'Toutes les cat&eacute;gories';
 $lang['any'] = 'Aucun';
-$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r?';
+$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r ?';
 $lang['areyousure_deleteproduct'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer ce produit, et toute l&#039;information l&#039;accompagnant ?';
 $lang['ascending'] = 'Ascendant';
 $lang['attribute_name'] = 'Nom de l&#039;attribut';
@@ -39,11 +39,11 @@ $lang['categorylisttemplates'] = 'Gabarits de la liste des cat&eacute;gories';
 $lang['categorylisttemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit de liste de cat&eacute;gories';
 $lang['centimeters'] = 'Centim&egrave;tres';
 $lang['checkbox'] = 'Case &agrave; cocher';
-$lang['confirm_copyattributes'] = 'Aany existing attribute sets for this product will be removed. Are you sure you want to continue?';
+$lang['confirm_copyattributes'] = 'Tous les jeux d&#039;attributs de ce produit vont &ecirc;tre supprim&eacute;s. &Ecirc;tes-vous s&ucirc;r ?';
 $lang['confirm_delete_hierarchy_node'] = 'Confirmez-vous la suppression de cet &eacute;l&eacute;ment ? Tous les produits qui l&#039;utilisent ne figureront plus dans la hi&eacute;rarchie.';
 $lang['confirm_import'] = 'Voulez-vous r&eacute;ellement effectuer cette action ?\n\nDes param&egrave;tres incorrects ou un fichier de configuration invalide peuvent corrompre le catalogue de produits et le rendre inutilisable.';
 $lang['copy'] = 'Copier';
-$lang['copy_attrib_sets'] = 'Copy Attribute Sets';
+$lang['copy_attrib_sets'] = 'Copier les jeux d&#039;attributs';
 $lang['copy_category'] = 'Copier la cat&eacute;gorie';
 $lang['createddate'] = 'Date de cr&eacute;ation';
 $lang['current_value'] = 'Valeur actuelle';
@@ -62,26 +62,27 @@ $lang['detailtemplates'] = 'Gabarits d&eacute;tails';
 $lang['detailtemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit d&eacute;tails';
 $lang['dimensions'] = 'Dimensions ';
 $lang['disabled'] = 'D&eacute;sactiv&eacute;';
+$lang['down'] = 'Descendre';
 $lang['draft'] = '&Eacute;bauche';
 $lang['dropdown'] = 'Menu d&eacute;roulant';
 $lang['dropdown_options'] = 'Options du menu d&eacute;roulant <em>(uniquement pour les champs de type Menu d&eacute;roulant)</em><br/><br/><em>(une option de menu par ligne)</em>';
 $lang['edit'] = 'Editer';
 $lang['edit_attribset'] = 'Editer les Attributs';
-$lang['edit_attribsets'] = '&Eacute;diter les sets d&#039;attributs';
-$lang['edit_attribsets_for'] = '&Eacute;diter les sets d&#039;attributs pour';
+$lang['edit_attribsets'] = '&Eacute;diter les jeux d&#039;attributs';
+$lang['edit_attribsets_for'] = '&Eacute;diter les jeux d&#039;attributs pour';
 $lang['edit_attributes'] = '&Eacute;diter les attributs';
 $lang['edit_category'] = 'Editer la cat&eacute;gorie';
 $lang['edit_category_fields'] = 'Editer les champs de la cat&eacute;gorie';
 $lang['edit_hierarchy_item'] = 'Editer l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie';
 $lang['error_attribset_exists'] = 'Il y a d&eacute;j&agrave; un attribut du m&ecirc;me nom';
-$lang['error_duplicate_sku'] = 'Plusieurs Valeurs SKU identiques trouv&eacute;es';
+$lang['error_duplicate_sku'] = 'Plusieurs valeurs SKU identiques trouv&eacute;es';
 $lang['error_fieldvalue_empty'] = 'Une valeur doit &ecirc;tre indiqu&eacute;e';
 $lang['error_fileformat'] = 'Probl&egrave;me de format de fichier';
 $lang['error_filenotfound'] = 'Fichier introuvable';
 $lang['error_fileopen'] = 'Erreur &agrave; l&#039;ouverture du fichier %s';
 $lang['error_invalidparent'] = 'Parent invalide (un element de hi&eacute;rarchie ne peut &ecirc;tre son propre parent)';
 $lang['error_invalid_name'] = 'La valeur du champ personnalis&eacute; est invalide (seuls les caract&egrave;res alphanum&eacute;riques sont autoris&eacute;s)';
-$lang['error_invalid_value'] = 'Invalid value specified';
+$lang['error_invalid_value'] = 'Valeur incorrecte entr&eacute;e';
 $lang['error_missingparam'] = 'Un param&egrave;tre requis est manquant ou invalide';
 $lang['error_nameused'] = 'Un &eacute;l&eacute;ment portant ce nom existe d&eacute;j&agrave;';
 $lang['error_nofieldtype'] = 'Choisisser le type du champ';
@@ -93,10 +94,10 @@ $lang['error_product_nameused'] = 'Un produit portant ce nom existe d&eacute;j&a
 $lang['error_product_notfound'] = 'Le produit d&eacute;sir&eacute; n&#039;a pas pu &ecirc;tre retrouv&eacute;';
 $lang['error_product_skuused'] = 'Cette valeur SKU est d&eacute;j&agrave; utilis&eacute;e par un autre produit';
 $lang['error_price_adjustment'] = 'La valeur d&#039;ajustement du prix est invalide pour l&#039;objet %s';
-$lang['error_upload_failed'] = 'L&#039;envoi du fichier a &eacute;chou&eacute;: %s';
-$lang['expire_six_months'] = 'Apr&egrave;s Six Mois';
-$lang['expire_one_year'] = 'Apr&egrave;s Un An';
-$lang['expire_two_year'] = 'Apr&egrave;s Deux Ans';
+$lang['error_upload_failed'] = 'L&#039;envoi du fichier a &eacute;chou&eacute; : %s';
+$lang['expire_six_months'] = 'Apr&egrave;s six mois';
+$lang['expire_one_year'] = 'Apr&egrave;s un an';
+$lang['expire_two_year'] = 'Apr&egrave;s deux ans';
 $lang['extra1'] = 'Champ suppl&eacute;mentaire 1';
 $lang['extra2'] = 'Champ suppl&eacute;mentaire 2';
 $lang['field'] = 'Champ';
@@ -110,7 +111,7 @@ $lang['go'] = 'Envoyer';
 $lang['help'] = '<h3>Que fait ce module ?</h3>
 <p>Ce module permet de d&eacute;finir, d&#039;organiser et d&#039;afficher les donn&eacute;es de produits et des cat&eacute;gories associ&eacute;es. Il peut s&#039;int&eacute;grer dans une solution de commerce &eacute;lectronique, mais aussi fonctionner de mani&egrave;re autonome. Les produits peuvent appartenir &agrave; une ou plusieurs cat&eacute;gories. Le prix et le poids des produits est g&eacute;r&eacute; par le module, et des informations suppl&eacute;mentaires (attributs) peuvent &ecirc;tre ajout&eacute;es. Chaque attribut peut d&eacute;finir une modification du prix du produit.  Un indicateur permet de d&eacute;finir si par d&eacute;faut un produit est ou non tax&eacute;.</p>
   <p>Le module permet d&#039;attacher jusqu&#039;&agrave; deux images &agrave; un produit, de d&eacute;finir des champs personnalis&eacute;s publics ou priv&eacute;s.</p>
-<h3>Fonctions:</h3>
+<h3>Fonctions :</h3>
 <ul>
   <li>Types d&#039;affichage</li>
     <ul>
@@ -158,6 +159,16 @@ $lang['help'] = '<h3>Que fait ce module ?</h3>
 <p>Il suffit d&#039;ins&eacute;rer la balise <strong>{Products}</strong> dans le contenu d&#039;une de vos pages, ou dans un de vos gabarits.</p>
 <p>Pour utiliser d&#039;autres fonctions, vous devez ajouter un ou plusieurs param&egrave;tres &agrave; la balise <strong>{Products}</strong>. La liste de ces param&egrave;tres figure un peu plus bas. Par exemple, pour afficher la liste des produits appartenant &agrave; une cat&eacute;gorie, utilisez une balise comme <code>{Products category=&#039;nom_de_la_categorie&#039;}</code></p>
 </ul>
+
+<h3>Plugins Smarty</h3>
+<p>Ce module d&eacute;finit un ou plusieurs plugins Smarty afin de vous permettre de r&eacute;cup&eacute;rer diff&eacute;rentes informations sur les produits &agrave; inclure dans les gabarits de produits :</p>
+<ul>
+  <li>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}
+  <p>Ce plugin permet la r&eacute;cup&eacute;ration de toutes les informations d&#039;une cat&eacute;gorie sp&eacute;cifique (s&eacute;lection par champ ID). Il peut de mani&egrave;re optionnelle assigner ces informations &agrave; une variable smarty (dans l&#039;exemple : <em>tmp</em>). Cette variable devient alors un objet contenant toutes les informations de la cat&eacute;gorie, y compris les valeurs des champs.<br/>Par exemple : <code>
+{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Nom de la cat&eacute;gorie = {$tmp->name}</code></p>
+  </li>
+</ul>
+
 <h3>Assistance</h3>
 <p>Ce module est fourni sans aucune assistance commerciale. Cependant, vous pouvez tout de m&ecirc;me obtenir de l&#039;aide:</p>
 <ul>
@@ -176,11 +187,11 @@ $lang['inches'] = 'Pouces';
 $lang['include_children'] = 'Avec les descendants ?';
 $lang['info_alnumonly'] = 'Caract&egrave;res alphanum&eacute;riques uniquement. Pas d&#039;espaces, de guillemets ou de combinaisons autres que lettres et chiffres.';
 $lang['info_attribtemplate'] = 'Les variables possibles sont : {$attrib_text},{$attrib_adjust},{$currency_symbol}';
-$lang['info_attributes_copied'] = 'Attributes Copied';
+$lang['info_attributes_copied'] = 'Attributs copi&eacute;s';
 $lang['info_autowatermark'] = 'La configuration des filigranes est celle du module CGExtensions';
 $lang['info_batchsize'] = 'Indiquez le nombre de lignes &agrave; traiter &agrave; chaque it&eacute;ration. D&egrave;s qu&#039;une it&eacute;ration est termin&eacute;e, le syst&egrave;me d&#039;importation d&eacute;marre la suivante. Si des probl&egrave;mes de m&eacute;moire ou de temps d&#039;ex&eacute;cution se produisent, r&eacute;duisez cette valeur, ou consultez le fournisseur de votre h&eacute;bergement.';
 $lang['info_cart_module_params'] = 'Ces param&egrave;tres sont pass&eacute;s au module panier s&eacute;lectionn&eacute;, &agrave; partir de la description et du r&eacute;sum&eacute; du produit.';
-$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
+$lang['info_copy_attribsets'] = 'Cette action copie les jeux d&#039;attributs (hors valeurs SKU) depuis un autre produit.';
 $lang['info_createfields'] = 'Cr&eacute;er automatiquement les champs inconnus ? <em>(cr&eacute;ation de champs de type texte)</em>';
 $lang['info_createcategories'] = 'Cr&eacute;er automatiquement les cat&eacute;gories de produits pr&eacute;sentes dans le fichier CSV, si elles n&#039;existent pas d&eacute;j&agrave;';
 $lang['info_createhierarchy'] = 'Cr&eacute;er automatiquement les &eacute;l&eacute;ments de hi&eacute;rarchie de produits pr&eacute;sentes dans le fichier CSV, si ils n&#039;existent pas d&eacute;j&agrave;';
@@ -193,7 +204,8 @@ $lang['info_handleimages'] = 'Lors de l&#039;importation, si un nom de fichier i
 $lang['info_imagepath'] = 'Chemin (relatif au r&eacute;pertoire uploads) des images r&eacute;f&eacute;renc&eacute;es par le fichier import&eacute; ';
 $lang['info_import_test_passed'] = 'Apr&egrave;s un examen pr&eacute;liminaire, le fichier semble correct.<br/>Cependant, il se peut qu&#039;il contienne tout de m&ecirc;me des erreurs qui ne pourront &ecirc;tre d&eacute;tect&eacute;es que lors de l&#039;importation.';
 $lang['info_price_adjustment'] = 'Les valeurs valides sont +-*#.##';
-$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
+$lang['info_prodnotfound'] = 'Cette option param&egrave;tre le comportement du site lorsqu&#039;une fiche produit est affich&eacute;e directement &agrave; la saisie d&#039;une URL, et que ce produit ne peut &ecirc;tre affich&eacute; (pour toutes raisons : d&eacute;sactiv&eacute;, supprim&eacute;, etc.).
+This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Les champs publics sont visibles par les utilisateurs.';
 $lang['label'] = '&Eacute;tiquette';
 $lang['label_skip'] = 'Ignorer';
@@ -230,41 +242,47 @@ $lang['param_action'] = 'Sp&eacute;cifie le comportement du module. Les valeurs
   </li>
   <li>search - Afficher un formulaire de recherche de produits multi-crit&egrave;res</li>
 </ul>';
-$lang['param_category'] = 'Lors de l&#039;utilisation <em>par d&eacute;faut</em> en mode sommaire, ce param&egrave;tre, qui devrait correspondre au nom d&#039;une cat&eacute;gorie existante, sera utilis&eacute; pour afficher seulement les entr&eacute;es qui sont dans cette cat&eacute;gorie (une liste s&eacute;par&eacute;e par des virgules peut &ecirc;tre fournie)';
-$lang['param_categorylisttemplate'] = 'Utile seulement avec l&#039;action categorylist, ce param&egrave;tre indique quel gabarit doit &ecirc;tre utilis&eacute; pour l&#039;affichage. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
-$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
+$lang['param_category'] = 'Lors de l&#039;utilisation en mode sommaire (<em>default</em>), ce param&egrave;tre, qui devrait correspondre au nom d&#039;une cat&eacute;gorie existante, sera utilis&eacute; pour afficher seulement les entr&eacute;es qui sont dans cette cat&eacute;gorie (une liste s&eacute;par&eacute;e par des virgules peut &ecirc;tre fournie)';
+$lang['param_categorylisttemplate'] = 'Utilis&eacute; seulement avec l&#039;action <em>categorylist</em>, ce param&egrave;tre indique quel gabarit doit &ecirc;tre utilis&eacute; pour l&#039;affichage. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
+$lang['param_categorylistdtltemplate'] = 'Utilis&eacute; seulement avec l&#039;action <em>categorylist</em>, ce param&egrave;tre indique quel gabarit doit &ecirc;tre utilis&eacute; pour l&#039;affichage du d&eacute;tail d&#039;une cat&eacute;gorie. Ce param&egrave;tre utilise un gabarit de liste de cat&eacute;gories... Si aucune valeur n&#039;est sp&eacute;cifi&eacute;e, c&#039;est le gabarit par d&eacute;faut de ce type qui est utilis&eacute;.';
 $lang['param_detailpage'] = 'Sp&eacute;cifie l&#039;id ou l&#039;alias de la page qui doit &ecirc;tre utilis&eacute;e pour afficher le d&eacute;tail.';
 $lang['param_detailtemplate'] = 'Ce param&egrave;tre sp&eacute;cifie quel gabarit devrait &ecirc;tre utilis&eacute; pour l&#039;affichage en mode d&eacute;tails. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
-$lang['param_field'] = 'Used only in the <em>fieldlist</em> this parameter is required to specify the name of a user defined property to create a list from.';
-$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
-$lang['param_hierarchy'] = 'Utilis&eacute; seulement avec l&#039;action 
-<em>default</em>, ce param&egrave;tre indique que seuls les produits appartenant &agrave; cet &eacute;l&eacute;ment de hi&eacute;rarchie doivent &ecirc;tre affich&eacute;s.  Des jokers peuvent &ecirc;tre utilis&eacute;s pour &eacute;tendre l&#039;affichage aux parent ou enfants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie indiqu&eacute;.  Par exemple {Products hierarchy=&#039;potirons*&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux descendants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;.  De m&ecirc;me, {Products hierarchy=&#039;*potirons&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux parents de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;';
+$lang['param_field'] = 'Utilis&eacute; seulement avec l&#039;action <em>fieldlist</em>, ce param&egrave;tre est obligatoire pour pr&eacute;ciser le nom du champ produit &agrave; utiliser pour cr&eacute;er la liste d&eacute;roulante.';
+$lang['param_fieldval'] = 'Utilis&eacute; seulement avec l&#039;action <em>default</em>, ce param&egrave;tre permet de sp&eacute;cifier la valeur d&#039;un champ pour limiter les r&eacute;sultats affich&eacute;s. Valeurs sp&eacute;ciales possibles : &quot;::null::&quot; - &quot;::notnull::&quot;';
+$lang['param_hierarchy'] = 'Utilis&eacute; seulement avec l&#039;action <em>default</em>, ce param&egrave;tre indique que seuls les produits appartenant &agrave; cet &eacute;l&eacute;ment de hi&eacute;rarchie doivent &ecirc;tre affich&eacute;s.  Des jokers peuvent &ecirc;tre utilis&eacute;s pour &eacute;tendre l&#039;affichage aux parent ou enfants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie indiqu&eacute;.  Par exemple {Products hierarchy=&#039;potirons*&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux descendants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;.  De m&ecirc;me, {Products hierarchy=&#039;*potirons&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux parents de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;';
 $lang['param_hierarchytemplate'] = 'Ce param&egrave;tre indique le gabarit &agrave; utiliser lors de l&#039;affichage de la hi&eacute;rarchie. Le gabarit de hi&eacute;rarchie par d&eacute;faut est utilis&eacute; si ce param&egrave;tre est absent ou vide.';
-$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
-$lang['param_pagelimit'] = 'Utilis&eacute; seulement avec l&#039;action <em>par d&eacute;faut</em>, ce param&egrave;tre sp&eacute;cifie combien d&#039;articles doivent &ecirc;tre list&eacute;s sur chaque page.';
+$lang['param_inline'] = 'Utilis&eacute; seulement avec l&#039;action <em>search</em>, ce param&egrave;tre sp&eacute;cifie que la page de r&eacute;sultats affich&eacute;e doit &ecirc;tre affich&eacute;e &quot;en ligne&quot; ou non.';
+$lang['param_pagelimit'] = 'Utilis&eacute; seulement avec l&#039;action <em>default</em>, ce param&egrave;tre sp&eacute;cifie combien d&#039;articles doivent &ecirc;tre list&eacute;s sur chaque page.';
 $lang['param_parent'] = 'Utilis&eacute; seulement avec l&#039;action <em>hierarchy</em>, ce param&egrave;tre indique quel est  l&#039;ID du premier &eacute;l&eacute;ment de la hi&eacute;rarchie &agrave; afficher';
 $lang['param_productid'] = 'Utilis&eacute; seulement avec l&#039;action d&eacute;tail, ce param&egrave;tre indique quels produits utiliser pour l&#039;affichage.';
-$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
-$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
-$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
-$lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
+$lang['param_resultpage'] = 'Utilis&eacute; seulement avec les actions <em>search</em> et <em>categorylist</em>, ce param&egrave;tre sp&eacute;cifie l&#039;ID ou l&#039;alias de page &agrave; utiliser pour afficher la liste des r&eacute;sultats.';
+$lang['param_searchfield'] = 'Utilis&eacute; seulement avec l&#039;action <em>search</em>, ce param&egrave;tre peut contenir une liste s&eacute;par&eacute;e par des virgules de noms de champs &agrave; inclure dans la recherche.';
+$lang['param_searchformtemplate'] = 'Utilis&eacute; seulement avec l&#039;action <em>search</em>, ce param&egrave;tre permet de d&eacute;finir le gabarit du formulaire de recherche.';
+$lang['param_showall'] = 'Utilis&eacute; seulement avec les actions <em>fieldlist</em> et <em>categorylist</em>, si ce param&egrave;tre est un entier diff&eacute;rent de 0, toutes les cat&eacute;gories (m&ecirc;me celles sans produits) seront affich&eacute;es.';
 $lang['param_sortorder'] = 'Sp&eacute;cifie l&#039;ordre des champs tri&eacute;s en mode sommaire. Les valeurs possibles sont:
 <ul>
   <li><strong>asc</strong> -- Ordre ascendant</li>
   <li>desc -- Order descendant</li>
 </ul>';
-$lang['param_sortby'] = 'Applicable seulement en mode sommaire, ce param&egrave;tre d&eacute;termine le tri des entr&eacute;es. Les valeurs possibles sont:
+$lang['param_sortby'] = 'Utilis&eacute; seulement avec les actions <em>summary</em>, <em>categorylist</em> et <em>search</em>, ce param&egrave;tre d&eacute;termine le tri des entr&eacute;es. Les valeurs possibles de tri sont :
 <ul>
-  <li><strong>product_name</strong></li>
-  <li>phone</li>
-  <li>fax</li>
-  <li>email</li>
-  <li>website -- L&#039;url du site internet</li>
-  <li>created -- La date de cr&eacute;ation de l\&#039;entr&eacute;e</li>
-  <li>modified --  La date de modification de l\&#039;entr&eacute;e</li>
-</ul>';
-$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
-$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
+  <li><strong>product_name</strong> -- nom de produit</li>
+  <li>id -- ID</li>
+  <li>weight -- Poids du produit</li>
+  <li>price -- Prix de base du produit</li>
+  <li>status -- Statut : <em>Ebauche</em> ou <em>Publi&eacute;</em></li>
+  <li>random -- Affiche une liste al&eacute;atoire &agrave; chaque affichage</li>
+  <li>created -- Date de cr&eacute;ation de l&#039;&eacute;l&eacute;ment</li>
+  <li>modified -- Date de modification de l&#039;&eacute;l&eacute;ment</li>
+  <li>f:fieldname -- Tri selon les valeurs des champs personnalis&eacute;s. Exemple : <em>f:couleur</em> o&ugrave; &quot;couleur&quot; est un champ personnalis&eacute;</li>
+</ul>
+<p>La vue de liste de cat&eacute;gories peut prendre en compte d&#039;autres options de tri :
+<ul>
+  <li>id -- ID de cat&eacute;gorie</li>
+  <li><strong>name</strong> -- Nom de cat&eacute;gorie</li>
+</ul></p>';
+$lang['param_sorttype'] = 'Utilis&eacute; seulement avec l&#039;action <em>default</em>, ce param&egrave;tre est utilis&eacute; pour convertir des valeurs d&#039;autres types pour le tri. Les valeurs valides sont : STRING, SIGNED et UNSIGNED. Si non pr&eacute;cis&eacute;, le type STRING est utilis&eacute; par d&eacute;faut.';
+$lang['param_summarypage'] = 'Utillis&eacute; seulement avec l&#039;action <em>hierarchy</em>, ce param&egrave;tre permet de pr&eacute;ciser l&#039;ID ou Alias de page &agrave; utiliser pour les liens vers la liste des produits d&#039;un &eacute;l&eacute;ment  de hi&eacute;rarchie.';
 $lang['param_summarytemplate'] = 'Ce param&egrave;tre sp&eacute;cifie quel gabarit doit &ecirc;tre utilis&eacute; en affichage mode sommaire. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
 $lang['parent'] = 'Parent ';
 $lang['postinstall'] = 'Le module Produits a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
@@ -278,8 +296,8 @@ $lang['product'] = 'Produit';
 $lang['productname'] = 'Nom du produit';
 $lang['products'] = 'Gestionnaire de produits';
 $lang['product_detail_settings'] = 'Param&egrave;tres D&eacute;tails du produit';
-$lang['product_editing_settings'] = 'Product Editing Settings';
-$lang['product_summary_settings'] = 'Product Summary Settings';
+$lang['product_editing_settings'] = 'Param&egrave;tres d&#039;&eacute;dition de produit';
+$lang['product_summary_settings'] = 'Param&egrave;tres des listes de produits';
 $lang['product_hierarchy'] = 'Hierarchie de produits';
 $lang['product_manager'] = 'Gestionnaire de produits';
 $lang['progress'] = 'Progression';
@@ -314,33 +332,33 @@ $lang['prompt_false'] = 'Faux';
 $lang['prompt_handleimages'] = 'G&eacute;rer les images ?';
 $lang['prompt_imagepath'] = 'Chemin des images';
 $lang['prompt_lengthunits'] = 'Unit&eacute;s de longueur';
-$lang['prompt_notfound_behavior'] = 'Quelle action doit &ecirc;tre r&eacute;alis&eacute;e lorsqu&#039;un produit ne peut &ecirc;tre affich&eacute;';
+$lang['prompt_notfound_behavior'] = 'Quelle action doit &ecirc;tre r&eacute;alis&eacute;e lorsqu&#039;un produit ne peut &ecirc;tre affich&eacute; ';
 $lang['prompt_notfound_404'] = 'G&eacute;n&eacute;rer une erreur 404';
 $lang['prompt_notfound_301'] = 'G&eacute;n&eacute;rer une redirection 301';
 $lang['prompt_notfound_errormsg'] = 'Afficher un message d&#039;erreur';
-$lang['prompt_notfound_msg'] = 'Message d&#039;erreur lorsqu&#039;un produit n&#039;est pas trouv&eacute;';
-$lang['prompt_notfound_page'] = 'Page pour faire les redirections permanentes';
-$lang['prompt_prod_detailpage'] = 'Page par d&eacute;faut pour voir le d&eacute;tail des produits';
+$lang['prompt_notfound_msg'] = 'Message d&#039;erreur lorsqu&#039;un produit n&#039;est pas trouv&eacute; ';
+$lang['prompt_notfound_page'] = 'Page pour faire les redirections permanentes ';
+$lang['prompt_prod_detailpage'] = 'Page par d&eacute;faut pour voir le d&eacute;tail des produits ';
 $lang['prompt_products_matching'] = 'Produits correspondant &agrave; %s';
-$lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
-$lang['prompt_summarysortorder'] = 'Ordre de tri par d&eacute;faut en mode sommaire';
-$lang['prompt_summarysorting'] = 'Champ de tri par d&eacute;faut en mode sommaire';
+$lang['prompt_summarypagelimit'] = 'Nombre de produits par d&eacute;faut et par page en mode Sommaire ';
+$lang['prompt_summarysortorder'] = 'Ordre de tri par d&eacute;faut en mode sommaire ';
+$lang['prompt_summarysorting'] = 'Champ de tri par d&eacute;faut en mode sommaire ';
 $lang['prompt_template'] = 'Source du gabarit';
 $lang['prompt_true'] = 'Vrai';
 $lang['prompt_urlprefix'] = 'Pr&eacute;fixe &agrave; utiliser sur toutes les URL cibl&eacute;es de ce module';
 $lang['prompt_use_detailpage_for_search'] = 'Utiliser cette page pour les r&eacute;sultats de recherche<em>(remplace le param&egrave;tre &#039;page des r&eacute;sultats de la recherche&#039; dans le module search)</em>';
 $lang['prompt_usehierpathurls'] = 'Utiliser le &#039;Hierarchy Path&#039; dans les urls des d&eacute;tails de produit';
 $lang['prompt_weightunits'] = 'Unit&eacute;s de poids';
-$lang['public'] = 'Est-ce un champ public?';
+$lang['public'] = 'Est-ce un champ public ?';
 $lang['published'] = 'Publi&eacute;';
 $lang['random'] = 'Au hasard';
 $lang['resettofactory'] = 'R&eacute;initialiser aux valeurs par d&eacute;faut';
 $lang['return'] = 'Retour';
 $lang['return_to_top'] = 'Retour en haut de page';
 $lang['root'] = 'Racine';
-$lang['search_description'] = 'Search Property Description';
+$lang['search_description'] = 'Description';
 $lang['search_expr'] = 'La requ&ecirc;te devra elle correspondent &agrave; la totalit&eacute;, ou au moins &agrave; l&#039;un des tests ci-dessous?';
-$lang['search_name'] = 'Search Property Name';
+$lang['search_name'] = 'Nom de produit';
 $lang['search_price'] = 'Gamme de prix';
 $lang['searchtemplate_addedit'] = 'Ajouter/Modifier le gabarit de formulaire de recherche';
 $lang['searchtemplates'] = 'Gabarit de recherche';
@@ -348,7 +366,7 @@ $lang['select_one'] = 'Choisir...';
 $lang['sku'] = 'SKU (identifiant de quantit&eacute; en stock)';
 $lang['sort_by'] = 'Tri par';
 $lang['sort_order'] = 'Ordre de tri';
-$lang['source'] = 'Source';
+$lang['source'] = 'Source ';
 $lang['status'] = 'Statut';
 $lang['submit'] = 'Soumettre';
 $lang['subscription'] = 'Abonnement';
@@ -374,6 +392,7 @@ $lang['title_detail_dflttemplate'] = 'Gabarit par d&eacute;faut pour l&#039;affi
 $lang['title_search_dflttemplate'] = 'Gabarit par d&eacute;faut des Nouvelles recherches';
 $lang['title_summary_dflttemplate'] = 'Gabarit par d&eacute;faut pour l&#039;affichage du sommaire';
 $lang['type'] = 'Type ';
+$lang['up'] = 'Remonter';
 $lang['update'] = 'Mise &agrave; jour';
 $lang['upload'] = 'Choisissez le fichier &agrave; envoyer';
 $lang['url_alias'] = 'Alias URL ';
@@ -381,13 +400,12 @@ $lang['valid'] = 'Valide';
 $lang['value'] = 'Valeur';
 $lang['values'] = 'Valeurs';
 $lang['view'] = 'Vue';
-$lang['viewable_fields'] = 'S&eacute;lectionner les champs personnalis&eacute;s &agrave; afficher dans le tableau';
+$lang['viewable_fields'] = 'S&eacute;lectionner les champs personnalis&eacute;s &agrave; afficher dans la liste';
 $lang['watermark_location'] = 'Emplacement du filigrane';
 $lang['weight'] = 'Poids';
 $lang['yes'] = 'Oui';
-$lang['utmz'] = '156861353.1291710225.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-747226238-1292160330212';
-$lang['utma'] = '156861353.1179877785.1291710225.1291927574.1292160330.5';
+$lang['utma'] = '156861353.1515266248.1292517082.1292517082.1292517082.1';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1292160330';
+$lang['utmz'] = '156861353.1292517082.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
