@@ -39,9 +39,11 @@ $lang['categorylisttemplates'] = 'Categorie Lijst Sjablonen';
 $lang['categorylisttemplate_addedit'] = 'Categorie Lijst Sjabloon toevoegen/aanpassen';
 $lang['centimeters'] = 'Centimeter';
 $lang['checkbox'] = 'Vinkvakje';
+$lang['confirm_copyattributes'] = 'Eventuele bestaande attributen voor dit product zullen worden verwijderd. Weet u zeker dat u door wilt gaan?';
 $lang['confirm_delete_hierarchy_node'] = 'Bent u zeker dat u deze node wilt verwijderen?  Elk product wat gebruik maakt van deze node zal niet meer onder een hi&euml;rarchie vallen.';
 $lang['confirm_import'] = 'Bent u zeker dat u dit wilt uitvoeren?\n\nVerkeerde instellingen of een verkeerd configuratiebestand kan het hele systeem in de war brengen. Wat resulteert in een niet werkende producten module.';
 $lang['copy'] = 'Kopie';
+$lang['copy_attrib_sets'] = 'Kopieer attributenset';
 $lang['copy_category'] = 'Categorie kopieren';
 $lang['createddate'] = 'Aangemaakt op';
 $lang['current_value'] = 'Huidige waarde';
@@ -54,11 +56,13 @@ $lang['delete_attribset'] = 'Attribuut verwijderen';
 $lang['delete_hierarchy_item'] = 'Verwijder Hierarchie Item';
 $lang['descending'] = 'Aflopend';
 $lang['description'] = 'Omschrijving';
+$lang['destination'] = 'Bestemming';
 $lang['details'] = 'Details ';
 $lang['detailtemplates'] = 'Detail Sjablonen';
 $lang['detailtemplate_addedit'] = 'Toevoegen/wijzigen Detail Sjabloon';
 $lang['dimensions'] = 'Dimensie';
 $lang['disabled'] = 'Uitgeschakeld';
+$lang['down'] = 'Naar beneden';
 $lang['draft'] = 'Concept';
 $lang['dropdown'] = 'Dropdown ';
 $lang['dropdown_options'] = 'Dropdown opties <em>(wordt alleen toegepast op velden)</em><br/><br/><em>(1 invoer per regel)</em>';
@@ -78,6 +82,7 @@ $lang['error_filenotfound'] = 'Bestand niet gevonden';
 $lang['error_fileopen'] = 'Probleem met openen van bestand %s';
 $lang['error_invalidparent'] = 'Ongeldige Ouder (een hierarchie node kan niet zijn eigen ouder zijn)';
 $lang['error_invalid_name'] = 'De aangepaste veld waarde die u heeft ingevoerd klopt niet (er staan ook niet alfnumerieke karakters in)';
+$lang['error_invalid_value'] = 'Ongeldige waarde opgegeven';
 $lang['error_missingparam'] = 'Een benodigde parameter mist of is niet geldig';
 $lang['error_nameused'] = 'Een item met deze naam is al in gebruik';
 $lang['error_nofieldtype'] = 'Selecteer a.u.b. een veldtype';
@@ -186,6 +191,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['hierarchy'] = 'Hierarchie';
 $lang['hierarchy_position'] = 'Hierarchie Positie';
+$lang['hierarchy_settings'] = 'Hierachie instellingen';
 $lang['id'] = 'Id ';
 $lang['imagetext'] = 'Afbeelding';
 $lang['image_handling_settings'] = 'Instellingen afbeelding afhandeling';
@@ -194,9 +200,11 @@ $lang['inches'] = 'Inches ';
 $lang['include_children'] = 'Inclusief onderliggenden?';
 $lang['info_alnumonly'] = 'Alleen alfanumerieke karakters. Geen witruimte, aanhalingstekens of letter/nummer combinaties';
 $lang['info_attribtemplate'] = 'Mogelijke waarden zijn: {$attrib_text}, {$attrib_adjust}, {$currency_symbol}';
+$lang['info_attributes_copied'] = 'Attributen gekopie&euml;rd';
 $lang['info_autowatermark'] = 'De watermerk instellingen zijn afkomstig uit de CGExtensions Module';
-$lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
+$lang['info_batchsize'] = 'Stel het aantal regels om uit te voeren per &#039;batch&#039; in. Nadat een batch is voltooid, zal de importer worden doorverwezen en doorgaan met de operatie. Als u verwacht dat er mogelijk geheugenfouten gaan ontstaan of time-outproblemen door het hoge aantal regels per keer, dan kunt u beter contact opnemen met uw hostingprovider of dit nummer lager instellen.';
 $lang['info_cart_module_params'] = 'Deze parameters worden doorgegeven aan de geselecteerde cart module vanuit het  product uitgebreid en opsomming displays';
+$lang['info_copy_attribsets'] = 'Deze actie zal de attributensets kopie&euml;ren (exclusief sku waardes) van een ander product';
 $lang['info_createfields'] = 'Maak onbekende productvelden automatisch aan? <em>(Ze worden dan aangemaakt als tekstveld)</em>';
 $lang['info_createcategories'] = 'Maak automatisch een productcategorie aan die voorkomt in het CSV file als deze nog niet bestaat';
 $lang['info_createhierarchy'] = 'Maak automatisch een product hi&euml;rarchie aan die voorkomt in het CSV file als deze nog niet bestaan';
@@ -206,8 +214,10 @@ $lang['info_duplicateproducts'] = 'Specificeer hoe het systeem moet handelen als
 $lang['info_fielddefs_tab'] = '<strong>Opmerking:</strong> De hier aanwezige velden zijn beschikbaar voor alle producten.';
 $lang['info_fieldproblems'] = 'Er is probleem ontstaan met het verwerken van een of meer aangemaakte velden.  Deze actie is correct uitgevoerd. maar het is verstandig alles te controleren en eventueel te herstellen.';
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
+$lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
 $lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
 $lang['info_import_test_passed'] = 'Een korte test heeft plaatsgevonden op het geselecteerde geselecteerde bestand en alles lijkt in orde.<br/>Dit is echter geen garantie dat er geen fouten in het bestand aanwezig zijn.';
+$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
 $lang['info_price_adjustment'] = 'Geaccepteerde waarden zijn +-*#.##';
 $lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Publieke velden zijn zichtbaar voor het publiek';
@@ -253,6 +263,7 @@ $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist acti
 $lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.';
 $lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.';
 $lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
+$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
@@ -283,7 +294,6 @@ $lang['param_sortby'] = 'Applicable only in the summary or search actions, this
 $lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
 $lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
 $lang['param_summarytemplate'] = 'Deze parameter geeft aan welke opsomming sjabloon er gebruikt moet worden. Als er geen geselecteerd wordt dan word de standaard sjabloon gebruikt.';
-$lang['param_useoldhierarchy'] = 'Use old hierarchy mode which generates a flat list of hierarchies below the current level.  This mode is deprecated and will be removed at a later date.';
 $lang['parent'] = 'Bovenliggende';
 $lang['postinstall'] = 'De Products module is geinstalleerd';
 $lang['postuninstall'] = 'De Products module is verwijderd inclusief alle bijbehorende data';
@@ -296,6 +306,8 @@ $lang['product'] = 'Product ';
 $lang['productname'] = 'Productnaam';
 $lang['products'] = 'Producten';
 $lang['product_detail_settings'] = 'Product Detail Instellingen';
+$lang['product_editing_settings'] = 'Product Wijzigen instellingen';
+$lang['product_summary_settings'] = 'Productsamenvatting instellingen';
 $lang['product_hierarchy'] = 'Producthierarchie';
 $lang['product_manager'] = 'Productmanager';
 $lang['progress'] = 'Voortgang';
@@ -336,10 +348,13 @@ $lang['prompt_notfound_301'] = 'Genereer een 301 redirect';
 $lang['prompt_notfound_errormsg'] = 'Toon een foutmelding';
 $lang['prompt_notfound_msg'] = 'Foutmelding als een product niet gevonden is';
 $lang['prompt_notfound_page'] = 'Pagina om permanent naar te verwijzen?';
+$lang['prompt_hierpage'] = 'Standaard pagina voor hie&auml;rchische weergave';
+$lang['prompt_prettyhierurls'] = 'Gebruik Pretty URL&#039;s voor de hie&auml;rchische weergave';
 $lang['prompt_prod_detailpage'] = 'Standaard Pagina voor Product Detail Overzichten';
 $lang['prompt_products_matching'] = 'Producten gelijk aan %s';
-$lang['prompt_summarysortorder'] = 'Standaard sorteervolgorde in opsomming mode';
-$lang['prompt_summarysorting'] = 'Standaard veldvolgorde in opsomming mode';
+$lang['prompt_summarypagelimit'] = 'Standaard paginalimiet in samenvattingsmodus';
+$lang['prompt_summarysortorder'] = 'Standaard sorteervolgorde in samenvattingsmodus';
+$lang['prompt_summarysorting'] = 'Standaard veldvolgorde in samenvattingsmodus';
 $lang['prompt_template'] = 'Sjabloon Bron';
 $lang['prompt_true'] = 'Wel';
 $lang['prompt_urlprefix'] = 'Te gebruiken prefix voor alle URLs die deze module gebruikt';
@@ -363,6 +378,7 @@ $lang['select_one'] = 'Kies &eacute;&eacute;n';
 $lang['sku'] = 'Uitlevereenheid ';
 $lang['sort_by'] = 'Sorteer op';
 $lang['sort_order'] = 'Sorteervolgorde';
+$lang['source'] = 'Bron';
 $lang['status'] = 'Status ';
 $lang['submit'] = 'Versturen';
 $lang['subscription'] = 'Lidmaatschap';
@@ -388,6 +404,7 @@ $lang['title_detail_dflttemplate'] = 'Standaard nieuw Detail Sjabloon';
 $lang['title_search_dflttemplate'] = 'Standaard nieuw Zoek Sjabloon';
 $lang['title_summary_dflttemplate'] = 'Standaard nieuwe Samenvatting Sjabloon';
 $lang['type'] = 'Type ';
+$lang['up'] = 'Omhoog';
 $lang['update'] = 'Bijwerken ';
 $lang['upload'] = 'Selecteer een bestand om te uploaden';
 $lang['url_alias'] = 'Alias in pagina url';
@@ -399,9 +416,9 @@ $lang['viewable_fields'] = 'Selecteer velden om in het tabel te tonen';
 $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.1269027775.1259416186.1274962409.1274984280.841';
-$lang['utmz'] = '156861353.1274898055.839.146.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,44349.new.html';
-$lang['qca'] = 'P0-431297011-1259416186230';
-$lang['utmb'] = '156861353.3.10.1274984280';
+$lang['utma'] = '156861353.1852221271.1287479092.1295778890.1295801371.96';
+$lang['utmz'] = '156861353.1295801371.96.62.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['qca'] = 'P0-161031897-1287479092171';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
